patch Wireshark to allow BER decoding for UDP payloads, until feature is released

flake-conversion
Trolli Schmittlauch 2020-07-01 20:05:50 +02:00
parent e99d45fa04
commit 192a1f6e38
2 changed files with 29 additions and 1 deletions

28
nixos/133dbc2.diff Normal file
View File

@ -0,0 +1,28 @@
From 133dbc21785ebcdf571063ee1c4bcf273733c97b Mon Sep 17 00:00:00 2001
From: Anders Broman <anders.broman@ericsson.com>
Date: Wed, 01 Jul 2020 08:40:03 +0200
Subject: [PATCH] BER: Add the posibillity to do "decode as" on an UDP port.
Change-Id: I2897b32b58f154c9998316b16d24bf97ef544153
Reviewed-on: https://code.wireshark.org/review/37628
Petri-Dish: Anders Broman <a.broman58@gmail.com>
Tested-by: Petri Dish Buildbot
Reviewed-by: Anders Broman <a.broman58@gmail.com>
---
diff --git a/epan/dissectors/packet-ber.c b/epan/dissectors/packet-ber.c
index 15c2bb8..16bbf4f 100644
--- a/epan/dissectors/packet-ber.c
+++ b/epan/dissectors/packet-ber.c
@@ -4654,9 +4654,10 @@
syntax_names[i].value = 0;
syntax_names[i].strptr = NULL;
/* allow the dissection of BER/DER carried over a TCP transport
by using "Decode As..." */
dissector_add_for_decode_as_with_preference("tcp.port", ber_handle);
+ dissector_add_for_decode_as_with_preference("udp.port", ber_handle);
ber_update_oids();
}

View File

@ -77,7 +77,7 @@ in
programs.wireshark =
{
enable = true;
@@ -4654,9 +4654,10 @@
syntax_names[i].value = 0;
syntax_names[i].strptr = NULL;
- /* allow the dissection of BER/DER carried over a TCP transport
+ /* allow the dissection of BER/DER carried over a TCP/UDP transport
by using "Decode As..." */
dissector_add_for_decode_as_with_preference("tcp.port", ber_handle);
package = pkgs.wireshark-qt;
package = pkgs.wireshark-qt.overrideAttrs (oldAttrs: rec { patches = oldAttrs.patches ++ [ ./133dbc2.diff ];});
};
programs.adb.enable = true;